@@ -1,5 +1,5 @@
-ref <- raster(system.file("external/reference.rst", package = "diffeR"))
-comp <- raster(system.file("external/comparison.rst", package = "diffeR"))
+ref <- rast(system.file("external/reference.rst", package = "diffeR"))
+comp <- rast(system.file("external/comparison.rst", package = "diffeR"))
 
 # Crosstab matrix, total difference, quantity difference and allocation difference at the map level:
 (ctmatCompRef <- crosstabm(comp, ref, percent = TRUE)) 
@@ -15,5 +15,3 @@ exchangeDij(ctmatCompRef)
 
 #
 overallComponentsPlot(comp, ref)
-
-
